==> lebiniou_3.54.1.orig.tar.gz: lebiniou-3.54.1/plugins/main/tv_diff3/tv_diff3.c <==
/*
 *  Copyright 1994-2021 Olivier Girondel
 *  Copyright 2019-2021 Tavasti
 *
 *  This file is part of lebiniou.
 *
 *  lebiniou is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  lebiniou is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
 */

#include "context.h"

#define MIN_DIFFERENCE 40 /* how much color value has to differ from initial
                             to be shown. Lower values show target better,
                             but also show more flickering */

uint32_t version = 0;
uint32_t options = BO_GFX|BO_LENS|BO_WEBCAM|BO_NORANDOM;
char desc[] = "Show cam pic which differs";
char dname[] = "TV diff 3";

enum LayerMode mode = LM_OVERLAY;


void
run(Context_t *ctx)
{
  Pixel_t *src1, *start, *src2, *dst;

  dst = start = passive_buffer(ctx)->buffer;

  xpthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
  src1 = ctx->cam_save[ctx->cam][0]->buffer;
  src2 = ctx->cam_ref0[ctx->cam]->buffer;
  for (; dst < start + BUFFSIZE * sizeof(Pixel_t); src1++, src2++, dst++) {
    if (((*src1 - *src2) > MIN_DIFFERENCE) ||
        ((*src2 - *src1) > MIN_DIFFERENCE) ) {
      *dst = abs(*src1 - *src2);
    } else {
      *dst = 0;
    }
  }
  xpthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
}

==> lebiniou_3.61.2.orig.tar.gz: lebiniou-3.61.2/plugins/main/tv_diff3/tv_diff3.c <==
/*
 *  Copyright 1994-2021 Olivier Girondel
 *  Copyright 2019-2021 Tavasti
 *
 *  This file is part of lebiniou.
 *
 *  lebiniou is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  lebiniou is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
 */

#include "context.h"
#include "pthread_utils.h"


#define MIN_DIFFERENCE 40 /* how much color value has to differ from initial
                             to be shown. Lower values show target better,
                             but also show more flickering */

uint32_t version = 0;
uint32_t options = BO_GFX | BO_LENS | BO_WEBCAM | BO_NORANDOM;
char desc[] = "Show cam pic which differs";
char dname[] = "TV diff 3";

enum LayerMode mode = LM_OVERLAY;


void
run(Context_t *ctx)
{
  Pixel_t *src1, *start, *src2, *dst;

  dst = start = passive_buffer(ctx)->buffer;

  if (!xpthread_mutex_lock(&ctx->cam_mtx[ctx->cam])) {
    src1 = ctx->cam_save[ctx->cam][0]->buffer;
    src2 = ctx->cam_ref0[ctx->cam]->buffer;
    for (; dst < start + BUFFSIZE * sizeof(Pixel_t); src1++, src2++, dst++) {
      if (((*src1 - *src2) > MIN_DIFFERENCE) ||
          ((*src2 - *src1) > MIN_DIFFERENCE) ) {
        *dst = abs(*src1 - *src2);
      } else {
        *dst = 0;
      }
    }
    xpthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
  }
}
